#!/bin/bash
# Author : Guth (guth@ploposor.com)
# Sources location : http://prdownloads.sourceforge.net/phpldapadmin/phpldapadmin-1.1.0.5.tar.gz?download

# program name/version
softversion='1.1.0.5'
softname='phpldapadmin'

# architecture/package version
arch='noarch'
#cpu='i686'
packageversion='52.1'

# number of parallel tasks of make
#ntasks='-j2'

# parameters needed for the build process
buildir=$(pwd)
package="$softname-$softversion-$arch-$packageversion"

# prepare the build result directory
dest="$buildir/$package"
rm -rf $dest
rm -f $package.*
mkdir -p $dest
mkdir -p $dest/install
mkdir -p $dest/usr/src/$softname-$softversion
mkdir -p $dest/usr/doc/$softname-$softversion
mkdir -p $dest/usr/share/$softname
mkdir -p $dest/etc/$softname

# make a slack-desc file
cat <<EOF > $dest/install/slack-desc
            |-----handy-ruler------------------------------------------------------|
phpldapadmin: Web-based LDAP browser to manage your LDAP server
phpldapadmin: 
phpldapadmin: phpLDAPadmin is a web-based LDAP client. It provides easy,
phpldapadmin: anywhere-accessible, multi-language administration for your LDAP
phpldapadmin: server. Its hierarchical tree-viewer and advanced search functionality
phpldapadmin: make it intuitive to browse and administer your LDAP directory.
phpldapadmin: Since it is a web application, this LDAP browser works on many
phpldapadmin: platforms, making your LDAP server easily manageable from any
phpldapadmin: location. phpLDAPadmin is the perfect LDAP browser for the LDAP
phpldapadmin: professional and novice alike. Its user base consists mostly of LDAP
phpldapadmin: administration professionals.
EOF

# extract sources
echo "extracting ..."
srcdir="$softname-$softversion"
cd $buildir
rm -rf $srcdir
tar zxf $srcdir.tar.gz
cd $srcdir

#patch -p 1 < $buildir/cvs_required.patch

# set correct permissions
chown -R root.root .
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;

# configure package for compilation

echo "configuring ..."

# copy the doc files

rm .cvsignore
rm config/.cvsignore

cp -a \
 INSTALL LICENSE VERSION doc \
 $dest/usr/doc/$softname-$softversion

cp -a \
 index.php hooks htdocs lib locale templates tools \
 $dest/usr/share/$softname/

cp  config/config.php.example $dest/etc/$softname/config.php.new
( cd $dest/usr/share/$softname/
    ln -s ../../../etc/$softname  config
)

# put the ZenWalk build and other needed files in the right directory
echo "setting perms ..."
cp -a $buildir/build-$softname.sh $dest/usr/src/$softname-$softversion/
#cp -a $buildir/cvs_required.patch $dest/usr/src/$softname-$softversion/
chown -R root.root $dest/usr/src/$softname-$softversion

# make the package and move it to the build directory

# create doinst.sh file
echo "config() {
  NEW=\"\$1.new\"
  OLD=\"\$1\"
  # If there's no config file by that name, mv it over:
  if [ ! -r \$OLD ]; then
    mv \$NEW \$OLD
  elif [ \"\`cat \$OLD | md5sum\`\" = \"\`cat \$NEW | md5sum\`\" ]; then
    # toss the redundant copy
    rm \$NEW
  fi
  # Otherwise, we leave the .new copy for netpkg to consider...
}

config etc/phpldapadmin/config.php

" > $dest/install/doinst.sh

chmod 755 $dest/install/doinst.sh



#------------------( Create The *.dep File )
echo "creating .dep ..."
echo -n "apache,php" > $buildir/$package.dep

cd $dest
makepkg -l y -c n $package.tgz
mv $package.tgz $buildir

# computes the md5sum signature for the package
echo "creating .md5 ..."
cd $buildir
md5sum $package.tgz > $package.md5

if [ "$1" == "--cleanup" ]; then
  rm -rf $dest
  rm -rf $srcdir
fi

